/* Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of getSchoolInfo
 *
 * getSchoolInfo is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

#include "getSchoolInfo.h"

/* Summary: Get parameters passed by user and contact webservice server
 *              to obtain some school information.
 * Usage: getSchoolInfo <url> <inep> [proxy_host [proxy_port [proxy_user
 *                                                      proxy_passwd]]]
 * Return: Exit status:
 *          1) Parameter error
 *          2) Soap error
 *          3) Invalid INEP error
 */
int main(int argc, char **argv)
{
    struct soap *soap = soap_new();
    struct ns1__getINEPInfoResponse schoolInfo;
    char *url, *inep, *validId;

    /* Initialization *
     *-----------------------------------------------------------------------
     * Verify parameters */
    if (argc < 3 || argc > 7)
    {
        fprintf(stderr, "Wrong number of parameters.\n");
        fprintf(stderr, "Usage: getSchoolInfo url INEP ");
        fprintf(stderr, "[proxy_host [proxy_port [proxy_userid ");
        fprintf(stderr, "proxy_passwd]]]\n");
        /* Parameter error */
        exit(1);
    }

    /* Set parameters passed by user
     * Basic information */
    url = argv[1];
    inep = argv[2];

    /* Proxy information */
    if (argc > 3 && argv[3][0] != '\0')
    {
        soap->proxy_host = argv[3];
    }
    if (argc > 4 && argv[4][0] != '\0')
    {
        soap->proxy_port = atoi(argv[4]);
    }
    if (argc > 5 && argv[5][0] != '\0')
    {
        soap->proxy_userid = argv[5];
        soap->proxy_passwd = argv[6];
    }

    /* Check if the given INEP is valid */
    if (soap_call_ns1__verifyId(soap, url, "", inep, &validId) != SOAP_OK)
    {
        soap_print_fault(soap,stderr);
        exit(2);
    }

    /* Invalid INEP? */
    if (strcmp(validId,"true")) {
        exit(3);
    }

    /* Valid INEP. Get school information */
    if (soap_call_ns1__getINEPInfo(soap, url, "", inep, &schoolInfo) != SOAP_OK)
    {
        soap_print_fault(soap, stderr);
        exit(2);
    }
    printf("%s\n", schoolInfo._getINEPInfoReturn->Name);
    printf("%s\n", schoolInfo._getINEPInfoReturn->INEP);
    printf("%s\n", schoolInfo._getINEPInfoReturn->CEP);
    printf("%s\n", schoolInfo._getINEPInfoReturn->UF);
    printf("%s\n", schoolInfo._getINEPInfoReturn->City);
    printf("%s\n", schoolInfo._getINEPInfoReturn->Address);

    soap_end(soap);
    soap_free(soap);

    /* Successful */
    exit(0);
}
