#!/bin/bash
# Copyright (C) 2004-2009 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of collect-agent
#
# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# Exit status:

# 0 - Success
# 3 - Error when loading configuration
# 4 - XML filename not defined at configuration file
# 5 - Client not found or without execution permission
# 6 - Error while collecting system data
# 7 - Client returned an error

#------------------------------------------------------------------------------
# Function: clientExec
# Execute client sender with all necessary parameters.
# The parameters are obtained from the global variables.
function clientExec()
{
    date +"%F %T - Sending data for the server."

    ${CLIENT} $*
    error=$?

    if test ${error} -ne 0; then
        date +"%F %T - ERROR: while sending data for the server."
        return ${error}
    fi
}

declare PREFIX="$(dirname $(readlink -f $0))"
source ${PREFIX}/load-config.sh || exit 3

if test -z "${XMLFILENAME}"; then
    printf "ERROR: XML filename not defined at configuration file.\n"
    exit 4
else
    # Create "data" directory if it does not exist
    mkdir -p $(dirname $XMLFILENAME)
fi
if test ! -x "${CLIENT}"; then
    printf "ERROR: Client not found or without execution permission.\n"
    printf "${SCRIPTPATH} finished.\n"
    exit 5
fi

# Collect system data
if ! ${XMLPARSER} "${SCRIPTSDIR}" "${XMLFILENAME}"; then
    date +"%F %T - ERROR: while collecting system data."
    exit 6
fi

date +"%F %T - New inventory collected."
if ! clientExec --inventory; then
    exit 7
fi

exit 0
