#!/bin/bash
# Copyright (C) 2004-2011 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR

# This file is part of collect-agent

# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

#------------------------------------------------------------------------------
# Function: date_comparator
#           This function compares the dates of the collected data files.
function date_comparator()
{
    # If traffic.txt file doesn't exist, this may the first time the script is
    # running. Thus, traffic.txt and previous-traffic.txt files are created.
    # The first line of traffic.txt contains the date of the first execution of
    # script
    if ! test -f "$TRAFFIC"; then
        echo $(date +%F) > $TRAFFIC
        touch $PREVIOUS_TRAFFIC
    else
    # If previous-traffic.txt was deleted, copy the contents of traffic.txt to
    # previous-traffic.txt. This is necessary to avoid FILE_DATE returning a
    # failure
        if ! test -f "$PREVIOUS_TRAFFIC"; then
            cp $TRAFFIC $PREVIOUS_TRAFFIC
            echo $(date +%F) > $TRAFFIC
    # If previous-traffic.txt exists, check if the last modification date is the
    # current date or not. If it's the second case, it means it's a new day and
    # traffic.txt will be copied to previous-traffic.txt. traffic.txt will
    # contain the new collected data
        else
            FILE_DATE=$(date -d"$(ls -l --time-style="+%F" \
                                  $PREVIOUS_TRAFFIC | awk '{ print $6 }')" +%s)
            CURRENT_DATE=$(date -d"$(date +%F)" +%s)
            if test $FILE_DATE -ne $CURRENT_DATE; then
                cp $TRAFFIC $PREVIOUS_TRAFFIC
                echo $(date +%F) > $TRAFFIC
            fi
        fi
    fi
}

#------------------------------------------------------------------------------

# Get directory prefix and path to source.int script
PREFIX="$(dirname $(readlink -f $0))"
PROJECT=$PREFIX/../scripts/collect/project/source.int

# Verify if this is not an UCA Classmate, UCA Server nor Projector ProInfo. If
# it is, do not collect network data and exit. Also exit if the user is not in
# the sudoers(1)
if test "$(bash $PROJECT)" != "0" || ! sudo -v &> /dev/null; then
    exit 0
fi

# Change to the script directory
cd $PREFIX

# Collected data from the current day
TRAFFIC="./traffic.txt"

# Collected data on the last day before the machine is disconnected
PREVIOUS_TRAFFIC="./previous-traffic.txt"

# Interfaces that have "Destination" the network 0.0.0.0
INTERFACES="./interfaces"

# Receive the address(es) and mask(s) filtered from "interfaces"
ADDR_MASK="./addr-mask"

# Used in the control of iptables rules. To verify if interfaces have not been
# added or removed
PREVIOUS_NETWORKS="./previous-networks"
NETWORKS="./networks"

# Temporary
TMP1="./tmp1"
TMP2="./tmp2"
TMP3="./tmp3"

# Comments of iptables rules
INPUT="INPUT_COUNTS"
OUTPUT="OUTPUT_COUNTS"

# Call the function date_comparator to check if traffic.txt already been
# copied to previous-traffic.txt in case of a new day has started
date_comparator

# Capture interfaces that have "Destination " the network 0.0.0.0
/sbin/route -n | awk '/^0.0.0.0/ {print $8}' > $INTERFACES

rm -rf $ADDR_MASK $NETWORKS

# Save on "ADDR_MASK" the address(es) and mask(s) filtered from "interfaces"
while read i; do
    /sbin/ifconfig $i | grep 'inet ' > $TMP1
    cat $TMP1 | cut -d ":" -f2 > $TMP2
    sed s/' '// < $TMP2 > $TMP3
    cat $TMP3 | cut -d " " -f1 >> $ADDR_MASK
    cat $TMP1 | cut -d ":" -f4 >> $ADDR_MASK
done < $INTERFACES

rm -rf $TMP1 $TMP2 $TMP3

# Replace the "." by " " to facilitate on time to read the input
sed -i 's/\./ /g' $ADDR_MASK

# Run the discover-network program to discover the local networks
./discover-network

# Check if files are present for verification of local networks
if ! test -f "$PREVIOUS_NETWORKS"; then
    cp $NETWORKS $PREVIOUS_NETWORKS
fi

rm -rf $ADDR_MASK $INTERFACES

# Variable to check if rules are included
TEST=$(sudo /sbin/iptables -L INPUT -n -v -x | grep $INPUT | head -n 1)

if test -z "$TEST"; then
    # If $TEST is empty, then the rule(s) does not exist. Create rules for each
    # internal network
    while read net && read int; do
        sudo /sbin/iptables -I INPUT -i $int ! -s $net -m comment \
             --comment $INPUT
        sudo /sbin/iptables -I OUTPUT -o $int ! -d $net -m comment \
             --comment $OUTPUT
    done < $NETWORKS
else
    # If new networks were added, first removes your old networks and then
    # added the new ones
    TEST_DIFF=$(diff $NETWORKS $PREVIOUS_NETWORKS)
    if test -n "$TEST_DIFF"; then
        while read net && read int; do
            sudo /sbin/iptables -D INPUT -i $int ! -s $net -m comment \
                 --comment $INPUT
            sudo /sbin/iptables -D OUTPUT -o $int ! -d $net -m comment \
                 --comment $OUTPUT
        done < $PREVIOUS_NETWORKS

        while read net && read int; do
            sudo /sbin/iptables -I INPUT -i $int ! -s $net -m comment \
                 --comment $INPUT
            sudo /sbin/iptables -I OUTPUT -o $int ! -d $net -m comment \
                 --comment $OUTPUT
        done < $NETWORKS
        cp $NETWORKS $PREVIOUS_NETWORKS
    fi
fi

# Variable that stores the current time
TIMESTAMP=$(date +%H:%M)

# Filter the result of "iptables -L INPUT/OUTPUT -n -v -x"
TRAFFICIN=$(sudo /sbin/iptables -L INPUT -n -v -x | grep  $INPUT | head -n 1)
TRAFFICOUT=$(sudo /sbin/iptables -L OUTPUT -n -v -x| grep $OUTPUT | head -n 1)

# Filter "TRAFFICIN/TRAFFICOUT" preparing to save in the file
IN=$(echo "$TRAFFICIN" | awk '{print $1,$2}')
OUT=$(echo "$TRAFFICOUT" | awk '{print $1,$2}')

# Save in the "traffic.txt" the collected data in a period of 5 minutes
echo "$TIMESTAMP $IN $OUT" >> $TRAFFIC

# Reset the counters of iptables rules to the next collection
sudo /sbin/iptables -Z
