#!/bin/bash

# Copyright (C) 2010 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of collect-agent
#
# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

#-----------------------------------------------------------------------------
# Function: collectTest
# Test the collect agent using the vectors define below and showing
# appropriate messages: "OK" when the result is the expected one and "FAILED"
# otherwise.
function collectTest()
{
    eval ${collect_files[${filesCounter}]}

    for (( ; counter <= ${testLimit[${tests}]} ; counter++ )); do
        echo -en "\n-----------------------------------------------"
        echo "--------------------------------------------------"
        echo "Test ${counter}/64"
        if test -n "${collect_before[${counter}]}"; then
            eval ${collect_before[${counter}]}
        fi
        echo ${collect_msgs[${counter}]}
        echo ""
        eval ${collect_calls[${counter}]}
        RETVAL=$?
        if test ${counter} -ge 7 -a ${counter} -le 13; then
            echo "XML: $(cat ${XMLFILENAME})"
        fi
        echo -en "\nResult: "
        if test ${counter} -eq 0 -o ${counter} -eq 14 \
                -o ${counter} -eq 26 -o ${counter} -eq 36 \
                -o ${counter} -eq 63 -o ${counter} -eq 64; then
            if test ${RETVAL} -eq 0; then
                echo "OK - exited with 0."
            else
                echo -n "FAILED - expected a correct behavior, but the "
                echo "agent returned ${RETVAL} (error). Call:"
                echo "${collect_calls[${counter}]}"
            fi
        else
            if test ${RETVAL} -ne 0; then
                echo "OK - exited with ${RETVAL}"
            else
                echo -n "FAILED - expected an error value return, but the "
                echo "agent returned 0 (success). Call:"
                echo "${collect_calls[${counter}]}"
            fi
        fi
        if test -n "${collect_after[${counter}]}"; then
            eval ${collect_after[${counter}]}
        fi
    done

    echo ""
    eval ${collect_files[${filesCounter}]}
}

# Execution
# Get the program env vars
declare PREFIX="$(dirname $(readlink -f $0) | sed 's/\/tests//')"
declare filesCounter=0
declare tests=0
declare counter=0
source ${PREFIX}/load-config.sh || exit 1

# Overwrite the log file name
OLDLOGFILE=${LOGFILE}
LOGFILE=${PREFIX}/tests/results.log
NETLOGFILE=${PREFIX}/net/network-monitor.log

# Test limit numbers for each module (collect-parser, collect-data.sh,
# network-monitor, agente.sh, and collect scripts)
testLimit=( "13" "25" "35" "58" "64" )

# Which module is being tested
collect_files=(
    "date +\"%F %T - collect-parser test started.\"; ((filesCounter++))"
    "date +\"%F %T - collect-parser test ended.\"; ((filesCounter++))"
    "date +\"%F %T - collect-data.sh test started.\"; ((filesCounter++))"
    "date +\"%F %T - collect-data.sh test ended.\"; ((filesCounter++))"
    "date +\"%F %T - network-monitor test started.\"; ((filesCounter++))"
    "date +\"%F %T - network-monitor test ended.\"; ((filesCounter++))"
    "date +\"%F %T - agent.sh test started.\"; ((filesCounter++))"
    "date +\"%F %T - agent.sh test ended.\"; ((filesCounter++))"
    "date +\"%F %T - collect scripts test started.\"; ((filesCounter++))"
    "date +\"%F %T - collect scripts test ended.\""
)

# Commands to execute before the test execution
collect_before=(
    # XML parser tests
    "" "" "" ""
    "mv ${XMLPARSER} ${XMLPARSER}_tmp"
    "chmod 000 ${DATADIR}"
    "chmod 000 ${XMLFILENAME}"
    "mv ${SCRIPTSDIR}/collect/inep/number.int ${SCRIPTSDIR}/collect/inep/XAq"
    "mv ${SCRIPTSDIR}/collect ${SCRIPTSDIR}/testando"
    "mv ${SCRIPTSDIR}/collect/inventory/os/distro.string \
${SCRIPTSDIR}/collect/inventory/os/novo.abobrinha"
    "mv ${SCRIPTSDIR}/collect/inep ${SCRIPTSDIR}/collect/inventory/memory/"
    "echo \"Q2d3dc1tjIHOF7pNr\" >> ${SCRIPTSDIR}/collect/use/network/RX.int; \
echo \"Q2d3dc1tjIHOF7pNr\" >> ${SCRIPTSDIR}/collect/inventory/disk.tree; \
echo \"Q2d3dc1tjIHOF7pNr\" >> \
    ${SCRIPTSDIR}/collect/inventory/os/kernel.string"
    "cp ${SCRIPTSDIR}/collect/inventory/disk.tree ${TMPDIR}/; \
sed -i 's/disk/dakdakmd\nq2/g' ${SCRIPTSDIR}/collect/inventory/disk.tree"
    "echo '<tagB><last type=\"boolean\" value=\"FaLsO\"/>\
<before dqwD=\"0\" r2m=\"-9\" typeeq valeu=\"1\"/></tagB>' >> ${XMLFILENAME}"
    # collect-data.sh tests
    "" ""
    "mv ${XMLPARSER} ${XMLPARSER}_tmp"
    "mv ${CLIENT} ${CLIENT}_temporary"
    "chmod 000 ${PREFIX}/load-config.sh"
    "chmod 000 ${PREFIX}/${DEFAULTCONFIG}"
    "chmod 000 ${OLDLOGFILE}"
    "chmod 000 ${OLDXMLFILENAME}"
    "cp ${OLDXMLFILENAME} ${TMPDIR}/; \
sed -i 's/</Sm d\nP\t91/g' ${XMLFILENAME} ${OLDXMLFILENAME}"
    "cp ${PREFIX}/${DEFAULTCONFIG} ${TMPDIR}/; \
sed -i 's/I/1ed\nP\t6301/g' ${PREFIX}/${DEFAULTCONFIG}"
    "cp ${XMLPARSER} ${TMPDIR}/; \
sed -i 's/[ain]/qX1 e26 mfrw/g' ${XMLPARSER}"
    "cp ${CLIENT} ${TMPDIR}/; \
sed -i 's/[ain]/qX1 e26 mfrw/g' ${CLIENT}"
    # network-monitor tests
    "" ""
    "cp ${PREFIX}/net/load-config.sh ${PREFIX}/net/load-config.sh_tmp; \
sed -i 's/[ai]/q1f42\n3ri09192je/g' ${PREFIX}/net/load-config.sh"
    "cp ${PREFIX}/net/network-monitor.conf \
${PREFIX}/net/network-monitor.conf_tmp; \
sed -i 's/[ai]/q1f42\n3ri09192je/g' ${PREFIX}/net/network-monitor.conf"
    "chmod 000 ${PREFIX}/net/load-config.sh"
    "chmod 000 ${PREFIX}/net/network-monitor.conf"
    "chmod 000 ${PREFIX}/net/network-monitor.log"
    "chmod 000 ${PREFIX}/net/data/load-network.log"
    "chmod 000 ${PREFIX}/net/tmp/rx.tmp"
    "chmod 000 ${PREFIX}/net/tmp/tx.tmp"
    # agent.sh tests
    "" ""
    "chmod 000 ${PREFIX}/collect-data.sh"
    "chmod 000 ${CLIENT}"
    "chmod 000 ${PREFIX}/load-config.sh"
    "chmod 000 ${NETMONITOR}"
    "chmod 000 ${PREFIX}/${DEFAULTCONFIG}"
    "chmod 000 ${OLDLOGFILE}"
    "cp ${PREFIX}/collect-data.sh  ${PREFIX}/collect-data.sh_old; \
sed -i 's/[ai]/1\n2dqW/g' ${PREFIX}/collect-data.sh"
    "cp ${CLIENT} ${CLIENT}_old; \
sed -i 's/[ai]/1\n2dqW/g' ${CLIENT}"
    "cp ${PREFIX}/load-config.sh ${PREFIX}/load-config.sh_old; \
sed -i 's/[ai]/1\n2dqW/g' ${PREFIX}/load-config.sh"
    "cp ${NETMONITOR} ${NETMONITOR}_old; \
sed -i 's/[ai]/1\n2dqW/g' ${NETMONITOR}"
    "cp ${PREFIX}/${DEFAULTCONFIG} ${PREFIX}/${DEFAULTCONFIG}_old; \
sed -i 's/[ai]/1\n2dqW/g' ${PREFIX}/${DEFAULTCONFIG}"
    "cp ${OLDLOGFILE} ${OLDLOGFILE}_old; \
sed -i 's/[ai]/1\n2dqW/g' ${OLDLOGFILE}"
    "chmod 000 ${PREFIX}/client"
    "chmod 000 ${CLIENTCONFDIR}"
    "chmod 000 ${DATADIR}"
    "chmod 000 ${TMPDIR}"
    "chmod 000 ${PREFIX}/net"
    "chmod 000 ${LOGDIR}"
    "chmod 000 ${PREFIX}/bin"
    "chmod 000 ${SCRIPTSDIR}"
    "bash ${PREFIX}/agent.sh; rm -f ${TMPDIR}/lastExec.tmp; \
crontab -l | sed 's/a/q1v lnto\n2 2 2 2 1 /g' | crontab -"
    # Collect scripts test
    "cp ${SCRIPTSDIR}/collect/mac-address/number.string ${TMPDIR}/num.str; \
sed -i 's/ifconfig/echo \"\"/g' \
${SCRIPTSDIR}/collect/mac-address/number.string"
    "cp ${SCRIPTSDIR}/collect/mac-address/number.string ${TMPDIR}/num.str; \
sed -i 's/ifconfig/echo \"E@-AC-XZ-42gdddQ#FVz\"/g' \
${SCRIPTSDIR}/collect/mac-address/number.string"
    "cp ${SCRIPTSDIR}/collect/mac-address/number.string ${TMPDIR}/num.str; \
sed -i 's/ifconfig/echo \"\"/g' \
${SCRIPTSDIR}/collect/mac-address/number.string"
    "cp ${SCRIPTSDIR}/collect/mac-address/number.string ${TMPDIR}/num.str; \
sed -i 's/ifconfig/echo \"E@-AC-XZ-42gdddQ#FVz\"/g' \
${SCRIPTSDIR}/collect/mac-address/number.string"
    "cp ${SCRIPTSDIR}/collect/mac-address/number.string ${TMPDIR}/num.str; \
sed -i \"s/{INTERFACE}/{INTERFACE} | sed 's\/ \/ \\\\\\t\/g'/g\" \
${SCRIPTSDIR}/collect/mac-address/number.string"
    "cp ${SCRIPTSDIR}/collect/mac-address/number.string ${TMPDIR}/num.str; \
sed -i \"s/{INTERFACE}/{INTERFACE} | sed 's\/ \/ \\\\\\t\/g'/g\" \
${SCRIPTSDIR}/collect/mac-address/number.string"
)

# Commands to execute after the test execution, recovering the original
# files state
collect_after=(
    # XML parser tests
    "" "" "" ""
    "mv ${XMLPARSER}_tmp ${XMLPARSER}"
    "chmod 755 ${DATADIR}"
    "chmod 644 ${XMLFILENAME}"
    "mv ${SCRIPTSDIR}/collect/inep/XAq ${SCRIPTSDIR}/collect/inep/number.int"
    "mv ${SCRIPTSDIR}/testando ${SCRIPTSDIR}/collect"
    "mv ${SCRIPTSDIR}/collect/inventory/os/novo.abobrinha \
${SCRIPTSDIR}/collect/inventory/os/distro.string"
    "mv ${SCRIPTSDIR}/collect/inventory/memory/inep ${SCRIPTSDIR}/collect/"
    "sed -i '/Q2d3dc1tjIHOF7pNr/d' ${SCRIPTSDIR}/collect/use/network/RX.int; \
sed -i '/Q2d3dc1tjIHOF7pNr/d' ${SCRIPTSDIR}/collect/inventory/disk.tree; \
sed -i '/Q2d3dc1tjIHOF7pNr/d' \
${SCRIPTSDIR}/collect/inventory/os/kernel.string"
    "mv ${TMPDIR}/disk.tree ${SCRIPTSDIR}/collect/inventory/"
    ""
    # collect-data.sh tests
    "" ""
    "mv ${XMLPARSER}_tmp ${XMLPARSER}"
    "mv ${CLIENT}_temporary ${CLIENT}"
    "chmod 644 ${PREFIX}/load-config.sh"
    "chmod 644 ${PREFIX}/${DEFAULTCONFIG}"
    "chmod 644 ${OLDLOGFILE}"
    "chmod 644 ${OLDXMLFILENAME}"
    "mv ${TMPDIR}/collect-data_old.xml ${DATADIR}/"
    "mv ${TMPDIR}/${DEFAULTCONFIG} ${PREFIX}/"
    "mv ${TMPDIR}/collect-parser ${PREFIX}/bin/"
    "mv ${TMPDIR}/run.sh ${PREFIX}/client/"
    # network-monitor tests
    "" ""
    "mv ${PREFIX}/net/load-config.sh_tmp ${PREFIX}/net/load-config.sh"
    "mv ${PREFIX}/net/network-monitor.conf_tmp \
${PREFIX}/net/network-monitor.conf; rm -Rf ${PREFIX}/net/dq1f42 \
${PREFIX}/net/network-monq1f42"
    "chmod 644 ${PREFIX}/net/load-config.sh"
    "chmod 644 ${PREFIX}/net/network-monitor.conf"
    "chmod 644 ${PREFIX}/net/network-monitor.log"
    "chmod 644 ${PREFIX}/net/data/load-network.log"
    "chmod 644 ${PREFIX}/net/tmp/rx.tmp"
    "chmod 644 ${PREFIX}/net/tmp/tx.tmp"
    # agent.sh tests
    "crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 644 ${PREFIX}/collect-data.sh; crontab -r; \
rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${CLIENT}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 644 ${PREFIX}/load-config.sh; crontab -r; \
rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${NETMONITOR}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 644 ${PREFIX}/${DEFAULTCONFIG}; crontab -r; \
rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 644 ${OLDLOGFILE}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "mv ${PREFIX}/collect-data.sh_old ${PREFIX}/collect-data.sh; crontab -r; \
rm -f ${TMPDIR}/lastExec.tmp"
    "mv ${CLIENT}_old ${CLIENT}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "mv ${PREFIX}/load-config.sh_old ${PREFIX}/load-config.sh; crontab -r; \
rm -f ${TMPDIR}/lastExec.tmp"
    "mv ${NETMONITOR}_old ${NETMONITOR}; crontab -r; \
rm -f ${TMPDIR}/lastExec.tmp"
    "mv ${PREFIX}/${DEFAULTCONFIG}_old ${PREFIX}/${DEFAULTCONFIG}; \
crontab -r; rm -f ${TMPDIR}/lastExec.tmp; rmdir ${PREFIX}/d1"
    "mv ${OLDLOGFILE}_old ${OLDLOGFILE}; crontab -r; \
rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${PREFIX}/client; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${CLIENTCONFDIR}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${DATADIR}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${TMPDIR}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${PREFIX}/net; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${LOGDIR}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${PREFIX}/bin; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "chmod 755 ${SCRIPTSDIR}; crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    # Collect scripts test
    "mv ${TMPDIR}/num.str ${SCRIPTSDIR}/collect/mac-address/number.string"
    "mv ${TMPDIR}/num.str ${SCRIPTSDIR}/collect/mac-address/number.string"
    "mv ${TMPDIR}/num.str ${SCRIPTSDIR}/collect/mac-address/number.string; \
crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "mv ${TMPDIR}/num.str ${SCRIPTSDIR}/collect/mac-address/number.string; \
crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
    "mv ${TMPDIR}/num.str ${SCRIPTSDIR}/collect/mac-address/number.string"
    "mv ${TMPDIR}/num.str ${SCRIPTSDIR}/collect/mac-address/number.string; \
crontab -r; rm -f ${TMPDIR}/lastExec.tmp"
)

# Execution vector
collect_calls=(
    # XML parser tests
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR}"
    "${XMLPARSER} ${XMLFILENAME} ${SCRIPTSDIR}"
    "${XMLPARSER}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    # collect-data.sh tests
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh help | tee -a ${OLDLOGFILE} \
2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/collect-data.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    # network-monitor tests
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} testando | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    "bash ${NETMONITOR} | tee -a ${NETLOGFILE} 2>> ${NETLOGFILE}"
    # agent.sh tests
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh aql21 | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    # Collect scripts test
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
    "${XMLPARSER} ${SCRIPTSDIR} ${XMLFILENAME}"
    "bash ${PREFIX}/agent.sh | tee -a ${OLDLOGFILE} 2>> ${OLDLOGFILE}"
)

# Description messages
collect_msgs=(
    # XML parser tests
    "Calling XML parser with correct arguments:"
    "Calling XML parser without the file parameter:"
    "Calling XML parser with parameters changed:"
    "Calling XML parser without parameters:"
    "Calling XML parser when file does not exist:"
    "Calling XML parser when \"data\" has no \
permissions:"
    "Calling XML parser when \"data/collect-parser\" has no \
permissions:"
    "Calling XML parser with \"inep/number.int\" renamed to \"XAq\":"
    "Calling XML parser with \"collect\" renamed to \"testando\":"
    "Calling XML parser with \"os/distro.string\" renamed to \"novo.tree\":"
    "Calling XML parser after moving \"collect/inep\" to inside \"memory\":"
    "Calling XML parser with corrupted scripts (echo \"Q2d3dc1tjIHOF7pNr\" >>\
network/RX.int, inventory/disk.tree, os/kernel.string):"
    "Calling XML parser with corrupted disk script (sed disk dakdakmd\\nq2):"
    "Calling XML parser with extra tags in xml data file:"
    # collect-data.sh tests
    "Calling collect-data.sh with all correct:"
    "Calling collect-data.sh with an extra parameter:"
    "Calling collect-data.sh when \"collect-parser\" file does not exist:"
    "Calling collect-data.sh when client (\"run.sh\") file does not exist:"
    "Calling collect-data.sh when \"load-config.sh\" has no permissions:"
    "Calling collect-data.sh when \"collect.conf\" has no permissions:"
    "Calling collect-data.sh when \"collect.log\" has no permissions:"
    "Calling collect-data.sh when old xml file has no permissions:"
    "Calling collect-data.sh with corrupted old xml data file \
(sed < Sm d\nP\t91):"
    "Calling collect-data.sh with corrupted \"collect.conf\" \
(sed I 1ed\nP\t6301):"
    "Calling collect-data.sh with corrupted \"collect-parser\" \
(sed [ain] qX1 e26 mfrw):"
    "Calling collect-data.sh with corrupted client (\"run.sh\") \
(sed [ain] qX1 e26 mfrw):"
    # network-monitor tests
    "Calling network-monitor.sh with all correct:"
    "Calling network-monitor.sh with an extra parameter:"
    "Calling network-monitor.sh with corrupted \"net/load-config.sh\" (sed \
[ai] q1f42\n3ri09192je):"
    "Calling network-monitor.sh with corrupted \"net/network-monitor.conf\" \
(sed [ai] q1f42\n3ri09192je):"
    "Calling network-monitor.sh when \"net/load-config.sh\" has no \
permissions:"
    "Calling network-monitor.sh when \"net/network-monitor.conf\" has no \
permissions:"
    "Calling network-monitor.sh when \"net/network-monitor.log\" has no \
permissions:"
    "Calling network-monitor.sh when \"net/data/load-network.log\" has no \
permissions:"
    "Calling network-monitor.sh when \"net/tmp/rx.tmp\" has no permissions:"
    "Calling network-monitor.sh when \"net/tmp/tx.tmp\" has no permissions:"
    # agent.sh tests
    "Calling agent.sh with all correct:"
    "Calling agent.sh with an extra parameter:"
    "Calling agent.sh when \"collect-data.sh\" has no permissions:"
    "Calling agent.sh when client has no permissions:"
    "Calling agent.sh when \"load-config.sh\" has no permissions:"
    "Calling agent.sh when \"network-monitor.sh\" has no permissions:"
    "Calling agent.sh when \"collect.conf\" has no permissions:"
    "Calling agent.sh when \"collect.log\" has no permissions:"
    "Calling agent.sh with corrupted \"collect-data.sh\" (sed [ai] 1\n2dqW):"
    "Calling agent.sh with corrupted client (\"run.sh\") (sed [ai] 1\n2dqW):"
    "Calling agent.sh with corrupted \"load-config.sh\" (sed [ai] 1\n2dqW):"
    "Calling agent.sh with corrupted \"network-monitor.sh\" \
(sed [ai] 1\n2dqW):"
    "Calling agent.sh with corrupted \"collect.conf\" (sed [ai] 1\n2dqW):"
    "Calling agent.sh with corrupted \"collect.log\" (sed [ai] 1\n2dqW):"
    "Calling agent.sh when \"client\" dir has no permissions:"
    "Calling agent.sh when \"client/conf\" dir has no permissions:"
    "Calling agent.sh when \"data\" dir has no permissions:"
    "Calling agent.sh when \"tmp\" dir has no permissions:"
    "Calling agent.sh when \"net\" dir has no permissions:"
    "Calling agent.sh when \"log\" dir has no permissions:"
    "Calling agent.sh when \"bin\" dir has no permissions:"
    "Calling agent.sh when \"scripts\" dir has no permissions:"
    "Calling agent.sh with corrupted crontab (sed 'a' 'q1v lnto\n2 2 2 2 1 ')"
    # Collect scripts test
    "Calling XML parser with \"ifconfig\" returning an empty string \
(sed ifconfig echo):"
    "Calling XML parser with \"ifconfig\" returning an invalid MAC \
(sed ifconfig echo \"E@-AC-XZ-42gdddQ#FVz\"):"
    "Calling agent.sh with \"ifconfig\" returning an empty string \
(sed ifconfig echo):"
    "Calling agent.sh with \"ifconfig\" returning an invalid MAC \
(sed ifconfig echo \"E@-AC-XZ-42gdddQ#FVz\"):"
    "Calling XML parser with \"ifconfig\" returning an invalid MAC \
(sed \"{INTERFACE}\" \"{INTERFACE} | sed 's\/ \/ \\\t\/g'/g\"):"
    "Calling agent.sh with \"ifconfig\" returning an invalid MAC \
(sed \"{INTERFACE}\" \"{INTERFACE} | sed 's\/ \/ \\\t\/g'/g\"):"
)

# Redirect all output to results.log
exec &>> ${LOGFILE}

date +"%F %T - Test started."

# Call collectTest to test the agent
for tests in $(seq 0 4); do
    echo -e "\n============================================================\n"
    collectTest;
done

echo -e "\n============================================================\n"
date +"%F %T - End of test."
