/* Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of database
 *
 * database is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* -------------------------------------------------------------------------- */
/* Enumerations */

comment on type category_enum is 'Enum type for the components category';
comment on type project_enum is 'Enum type for the MEC project which the '
    'machines belong to';
comment on type class_enum is 'Enum type for the classification of the '
    'machines according to their availability : green if communication occured '
    'at most 10 days ago, yellow if it ocurred between 10 and 30, and red if '
    'it has not occured for more than 30 days)';

/* -------------------------------------------------------------------------- */
/* Staging Areas */

comment on table sa_inventory is 'Transition table with temporary machines '
    'inventory data';
comment on column sa_inventory.inep is 'Longest INEP has 10 characters';
comment on column sa_inventory.hd_model is 'Longest HD model has 47 characters';
comment on column sa_inventory.processor is 'Longest processor model has 46 '
    'characters';
comment on column sa_inventory.os_distro is 'Longest OS distro has 35 '
    'characters';
comment on column sa_inventory.kernel is 'Longest kernel version has 24'
    'characters';
comment on table sa_net_usage is 'Transition table with temporary network '
    'usage data per machine';
comment on column sa_net_usage.insertion_date is 'To avoid using lock during '
    'the load';

/* -------------------------------------------------------------------------- */
/* Data Warehouse */

comment on table dim_date is 'Dimension table with dates representing each '
    'load done';
comment on table dim_school is 'Dimension table with data about the schools. '
    'Since this table is loaded apart from the rest of the tables, this is the '
    'only one who would not need the load_date field';
comment on column dim_school.city is 'Longest city name has 32 characters';
comment on column dim_school.school is 'MEC database limit for school names is '
    '100 characters';
comment on column dim_school.address is 'Longest address has 70 characters';
comment on table dim_component is 'Dimension table of software and hardware '
    'components';
comment on column dim_component.description is 'HD model, OS type, processor '
    'model and memory size';
comment on column dim_component.detail is 'HD size and OS distro';
comment on table dim_machine is 'Dimension table with machines inventory';
comment on table fact_inventory is 'Fact table with the history of machines '
    'connections and their inventory';
comment on table fact_alert is 'Fact table with the history of machines '
    'modifications';
comment on column fact_alert.hd_alert is 'First HD changes';
comment on table fact_net_usage is 'Fact table with the history of network '
    'usage per machine and 5 minutes sample';
comment on table control is 'Control table with the starting and ending times '
    'of each load process';

/* -------------------------------------------------------------------------- */
/* Data Marts */

comment on table dm_school is 'Data mart table with data about the schools '
    'used by fast search';
comment on column dm_school.fts_school is 'Full text search field for schools';
comment on column dm_school.nud_avail is 'It indicates if the school has '
    'already sent some network usage data';
comment on table dm_avail_state is 'Data mart with availability per state';
comment on table dm_avail_city is 'Data mart with availability per city';
comment on table dm_avail_school is 'Data mart with availability per school';
comment on table dm_avail_machine is 'Data mart with availability per machine';
comment on column dm_avail_machine.total_contacts is '89 years seems enough';
comment on column dm_avail_machine.days_last_contact is '89 years seems enough';
comment on table dm_avail_state_history is 'Data mart with the history '
    'of availability per state for the last 6 months';
comment on table dm_avail_city_history is 'Data mart with the history of '
    'availability per city for the last 6 months';
comment on table dm_invent_machine is 'Data mart with the machines inventory';
comment on table dm_audit_zm_school is 'Data mart with schools without any '
    'machine communicating';
comment on table dm_alert_state is 'Data mart with alerts per state';
comment on table dm_alert_city is 'Data mart with alerts per city';
comment on table dm_alert_school is 'Data mart with alerts per school';
comment on table dm_alert_machine is 'Data mart with machines alerts';
comment on table dm_alert_state_history is 'Data mart with the history of '
    'alerts per state for the last 6 months';
comment on table dm_alert_city_history is 'Data mart with the history of '
    'alerts per city for the last 6 months';
comment on table dm_net_usage_monthly is 'Data mart with network usage '
    'per school with 4 hours sample';
comment on table dm_net_usage_weekly is 'Data mart with network usage '
    'per school with 1 hour sample';
comment on table dm_net_usage_daily is 'Data mart with network usage per '
    'school with 5 minutes sample';
