/* Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of database
 *
 * database is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* Data mart table with data about the schools used by fast search */
create table dm_school (
    inep       text     not null,
    region     text     not null,
    state      text     not null,
    city       text     not null,
    school     text     not null,
    code       text,
    address    text,
    fts_school tsvector not null, /* Full text search field for schools */
    nud_avail  boolean  default false not null
    /* It indicates if the school has already sent some network usage data */
);

/* -------------------------------------------------------------------------- */
/* Last load availability tables */

/* Data mart table of availability per state */
create table dm_avail_state (
    project project_enum default 'proinfo' not null,
    region  text         not null,
    state   text         not null,
    total   integer      not null,
    green   integer      not null,
    yellow  integer      not null,
    red     integer      not null
);

/* Data mart table of availability per city */
create table dm_avail_city (
    project project_enum default 'proinfo' not null,
    region  text         not null,
    state   text         not null,
    city    text         not null,
    total   integer      not null,
    green   integer      not null,
    yellow  integer      not null,
    red     integer      not null
);

/* Data mart table of availability per school */
create table dm_avail_school (
    project project_enum default 'proinfo' not null,
    region  text         not null,
    state   text         not null,
    city    text         not null,
    inep    text         not null,
    school  text         not null,
    total   integer      not null,
    green   integer      not null,
    yellow  integer      not null,
    red     integer      not null
);

/* Data mart table with availability per machine */
create table dm_avail_machine (
    project           project_enum default 'proinfo' not null,
    region            text         not null,
    state             text         not null,
    city              text         not null,
    inep              text         not null,
    school            text         not null,
    machine           macaddr      not null,
    color             class_enum   not null,
    first_contact     date         not null,
    last_contact      date         not null,
    total_contacts    smallint     not null, /* 89 years seems enough */
    month_contacts    smallint     not null,
    days_last_contact smallint     not null  /* Ditto */
);

/* -------------------------------------------------------------------------- */
/* History availability tables */

/* Data mart table with the history of availability per state for the last 6
 * months */
create table dm_avail_state_history (
    project      project_enum default 'proinfo' not null,
    contact_date date         not null,
    region       text         not null,
    state        text         not null,
    total        integer      not null,
    green        integer      not null,
    yellow       integer      not null,
    red          integer      not null
);

/* Data mart table with the history of availability per city for the last 6
 * months */
create table dm_avail_city_history (
    project      project_enum default 'proinfo' not null,
    contact_date date         not null,
    region       text         not null,
    state        text         not null,
    city         text         not null,
    total        integer      not null,
    green        integer      not null,
    yellow       integer      not null,
    red          integer      not null
);

/* -------------------------------------------------------------------------- */
/* Last load inventory table */

/* Data mart table with the machines inventory */
create table dm_invent_machine (
    project      project_enum default 'proinfo' not null,
    contact_date date         not null,
    region       text         not null,
    state        text         not null,
    city         text         not null,
    inep         text         not null,
    school       text         not null,
    machine      macaddr      not null,
    os_distro    text         not null,
    processor    text         not null,
    memory_size  integer      not null,
    hd_size      integer      not null
);

/* -------------------------------------------------------------------------- */
/* Last load audit table */

/* Data mart table with schools without any machine communicating */
create table dm_audit_zm_school (
    project project_enum default 'proinfo' not null,
    region  text         not null,
    state   text         not null,
    city    text         not null,
    inep    text         not null,
    school  text         not null
);

/* -------------------------------------------------------------------------- */
/* Last load alert tables */

/* Data mart table with alerts per state */
create table dm_alert_state (
    project       project_enum default 'proinfo' not null,
    region        text         not null,
    state         text         not null,
    memory_amount integer      not null,
    hd_amount     integer      not null
);

/* Data mart table with alerts per city */
create table dm_alert_city (
    project       project_enum default 'proinfo' not null,
    region        text         not null,
    state         text         not null,
    city          text         not null,
    memory_amount integer      not null,
    hd_amount     integer      not null
);

/* Data mart table with alerts per school */
create table dm_alert_school (
    project       project_enum default 'proinfo' not null,
    region        text         not null,
    state         text         not null,
    city          text         not null,
    inep          text         not null,
    school        text         not null,
    memory_amount integer      not null,
    hd_amount     integer      not null
);

/* Data mart table with machines alerts */
create table dm_alert_machine (
    project         project_enum default 'proinfo' not null,
    region          text         not null,
    state           text         not null,
    city            text         not null,
    inep            text         not null,
    school          text         not null,
    machine         macaddr      not null,
    old_date        date         not null,
    new_date        date         not null,
    os_distro       text         not null,
    processor       text         not null,
    old_memory_size integer      not null,
    new_memory_size integer      not null,
    old_hd_size     integer      not null,
    new_hd_size     integer      not null,
    memory_alert    boolean      default false not null,
    hd_alert        boolean      default false not null
);

/* -------------------------------------------------------------------------- */
/* History alert tables */

/* Data mart table with the history of alerts per state for the last 6 months */
create table dm_alert_state_history (
    project       project_enum default 'proinfo' not null,
    contact_date  date         not null,
    region        text         not null,
    state         text         not null,
    memory_amount integer      not null,
    hd_amount     integer      not null
);

/* Data mart table with the history of alerts per city for the last 6 months */
create table dm_alert_city_history (
    project       project_enum default 'proinfo' not null,
    contact_date  date         not null,
    region        text         not null,
    state         text         not null,
    city          text         not null,
    memory_amount integer      not null,
    hd_amount     integer      not null
);

/* -------------------------------------------------------------------------- */
/* Network usage tables per school and different samples */

/* Data mart table with network usage per school with 4 hours sample */
create table dm_net_usage_monthly (
    state          text      not null,
    city           text      not null,
    inep           text      not null,
    school         text      not null,
    collect_time   timestamp not null,
    down_kbits_avg bigint    not null,
    up_kbits_avg   bigint    not null,
    down_kbits_max bigint    not null,
    up_kbits_max   bigint    not null
);

/* Data mart table with network usage per school with 1 hour sample */
create table dm_net_usage_weekly (
    state          text      not null,
    city           text      not null,
    inep           text      not null,
    school         text      not null,
    collect_time   timestamp not null,
    down_kbits_avg bigint    not null,
    up_kbits_avg   bigint    not null,
    down_kbits_max bigint    not null,
    up_kbits_max   bigint    not null
);

/* Data mart table with network usage per school with 5 minutes sample */
create table dm_net_usage_daily (
    state        text      not null,
    city         text      not null,
    inep         text      not null,
    school       text      not null,
    collect_time timestamp not null,
    down_kbits   bigint    not null,
    up_kbits     bigint    not null
);
