/* Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of database
 *
 * database is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* Create function that updates the data warehouse dimension tables using the
 * new data in the staging area, removing trailing white spaces from both
 * extremes of the text types */
create or replace function load_dim_dw() returns integer as $$
declare
    count_total integer := 0;
    tmp integer;
    load_date_id integer;
    min_date date;
/* -------------------------------------------------------------------------- */
begin
    raise log 'Data warehouse dimension load start point: %', current_timestamp;

    /* Create and populate staging area temporary table to be used by the
     * loading script as the source */
    create temporary table tmp_inventory as
        select distinct * from sa_inventory where contact_date < current_date;

    /* ---------------------------------------------------------------------- */
    /* Update dimension tables */

    raise log 'Inserting "current_date" into "dim_date"...';
    select id into load_date_id from dim_date where load_date = current_date;
    if load_date_id is null then
        insert into dim_date (load_date) values (current_date) returning id into
            load_date_id;
        raise log 'Done - 1 row inserted';
        count_total := 1;
    else
        raise log 'Done - row already inserted, using it';
    end if;

    raise log 'Inserting new component data into "dim_component"...';
    insert into dim_component (load_date, category, description, detail)
        select distinct load_date_id, 'os'::category_enum, trim(both from
            os_type), trim(both from os_distro) from tmp_inventory
        union all select distinct load_date_id, 'kernel'::category_enum,
            trim(both from kernel), null from tmp_inventory
        union all select distinct load_date_id, 'processor'::category_enum,
            trim(both from processor), null from tmp_inventory
        union all select distinct load_date_id, 'hd'::category_enum, trim(both
            from hd_model), hd_size::text from tmp_inventory
        union all select distinct load_date_id, 'hd'::category_enum, trim(both
            from hd2_model), hd2_size::text from tmp_inventory where hd2_model
            is not null
        except select load_date_id, category, description, detail from
            dim_component;
    get diagnostics tmp = ROW_COUNT;
    count_total := count_total + tmp;
    raise log 'Done - % rows inserted', tmp;

    raise log 'Updating project field of old machines inside "dim_machine"...';
    update dim_machine m set project = i.project
        from tmp_inventory i, dim_school s where i.machine = m.machine and
        i.inep = s.inep and s.id = m.school_id and i.project <> m.project;
    get diagnostics tmp = ROW_COUNT;
    count_total := count_total + tmp;
    raise log 'Done - % rows updated', tmp;

    raise log 'Inserting new machine data into "dim_machine"...';
    insert into dim_machine (load_date, school_id, machine, project)
        select distinct on (id, machine) load_date_id, id, machine, project
            from tmp_inventory i, dim_school s where i.inep = s.inep
        except select load_date_id, school_id, machine, project from
            dim_machine;
    get diagnostics tmp = ROW_COUNT;
    count_total := count_total + tmp;
    raise log 'Done - % rows inserted', tmp;

    /* ---------------------------------------------------------------------- */
    /* Update control table and clean staging area tables */

    raise log 'Updating "control" table with current transaction...';
    insert into control (name, start_time, end_time, total) values ('dw dim',
        current_timestamp, clock_timestamp(), count_total);
    raise log 'Done';

    raise log 'Data warehouse dimension load end point: % (started at %) - '
        'total of % rows', clock_timestamp(), current_timestamp, count_total;

    return count_total + 1;
end;
$$ language plpgsql;
