/* Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of database
 *
 * database is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* Create function that updates the data warehouse network usage tables */
create or replace function load_nu_dw(load_date_id integer) returns integer as
    $$
declare
    count_total integer := 0;
    tmp integer;
    min_date date;
/* -------------------------------------------------------------------------- */
begin
    raise log 'Data warehouse network usage load start point: %',
        current_timestamp;

    /* Create and populate staging area temporary table to be used by the
     * loading script as the source */
    create temporary table tmp_net_usage as
        select distinct * from sa_net_usage where insertion_date < current_date;

    /* ---------------------------------------------------------------------- */
    /* Update network usage fact table */

    raise log 'Inserting new network usage data into "fact_net_usage"...';
    insert into fact_net_usage (load_date, machine_id, collect_time, down_kbits,
        down_packages, up_kbits, up_packages)
        select load_date_id, m.id, collect_time, down_kbits, down_packages,
            up_kbits, up_packages from tmp_net_usage n, dim_machine m,
            dim_school s where n.machine = m.machine and n.inep = s.inep and
            m.school_id = s.id;
    get diagnostics tmp = ROW_COUNT;
    count_total := count_total + tmp;
    raise log 'Done - % rows inserted', tmp;

    /* ---------------------------------------------------------------------- */
    /* Update control table and clean staging area tables */

    raise log 'Updating "control" table with current transaction...';
    insert into control (name, start_time, end_time, total) values ('dw net '
        'usage', current_timestamp, clock_timestamp(), count_total);
    raise log 'Done';

    raise log 'Data warehouse load end point: % (started at %) - total of % '
        'rows', clock_timestamp(), current_timestamp, count_total;

    return count_total + 1;
end;
$$ language plpgsql;
