/*
 * seed2_doc.js
 *
 * Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of portal
 *
 * portal is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/*
 * This file contains all functions used in SEED2 project page:
 * Monitoramento Automatico dos Laboratorios das Escolas Publicas Brasileiras.
 * We used Web Services concepts with AJAX to get information about dynamic
 * contents (i.e. new versions of documentations)
 *
 * @author Rubens Massayuki Suguimoto
 */

var XMLConf = UTILS_OpenXMLFile("http://proinfodata.c3sl.ufpr.br/seed/conf/conf.xml");
var hostService = UTILS_GetTag(XMLConf, "host");
var services = UTILS_GetTag(XMLConf, "services");
var installService = UTILS_GetTag(XMLConf, "installservice");
var docService = UTILS_GetTag(XMLConf, "docservice");
var seed2Service = UTILS_GetTag(XMLConf, "seed2service");

/**
 * @brief Parse AJAX HTTP SOAP response.
 *
 * @param HttpRequest    XML HTTP Request object with SOAP response.
 * @return   empty string
 *
 * @author Rubens Massayuki Suguimoto
 * @author Renan Franca de Miranda
 */
function receiveResponse(HttpRequest) {

    var Status;
    var list, response;
    var i,j;
    var content;
    var li, a, img, div_top, div_descr, span_name, span_size, span_date, span_descr;
    var link, name, date, size, description;
    var responseElement;
    var hrefId, multiRefId;
    var multiref;

    if (HttpRequest.readyState == 4)
    {
        try
        {
            Status = HttpRequest.status;
        }
        catch(e)
        {
            document.write(e);
            return "";
        }
        if(Status == 200)
        {
            response = HttpRequest.responseXML.getElementsByTagName("getDocumentsReturn");
            list = document.createElement("ul");
            list.setAttribute("class","none");
            if(response.length != 0)
            {
                for(j=0; j<response.length; j++)
                {
                    responseElement = null;
                    /* This if treats the normal WB response. (without multiRef) */
                    if(response[j].getAttribute("xsi:nil") != "true" && response[j].getAttribute("xsi:type") == "ns1:Seed2Document")
                    {
                        responseElement = response[j];
                    }
                    /* This treats the response with multiRef */
                    else if(response[j].hasAttribute("href") == true)
                    {
                        multiref = HttpRequest.responseXML.getElementsByTagName("multiRef");
                        i = 0
                            hrefId = response[j].getAttribute("href").replace("#","");

                        while(responseElement == null)
                        {
                            multiRefId = multiref[i].getAttribute("id");
                            if(multiRefId == hrefId){
                                responseElement = multiref[i];
                            }
                            i++;
                        }
                    }

                    if (responseElement != null)
                    {
                        /* creates HTML */
                        li = document.createElement("li");
                        li.setAttribute("id",j);

                        a = document.createElement("a");
                        link = responseElement.getElementsByTagName("URL");
                        link = UTILS_GetNodeText(link[0]);
                        a.setAttribute("href",link);

                        img = document.createElement("img");
                        img.setAttribute("src","../image/baixar_pdf_verde.png");

                        a.appendChild(img);
                        li.appendChild(a);

                        span_name = document.createElement("span");
                        span_name.setAttribute("class","name");
                        name = responseElement.getElementsByTagName("Name");
                        name = UTILS_GetNodeText(name[0]);
                        span_name.innerHTML = name;

                        span_size = document.createElement("span");
                        span_size.setAttribute("class","size");
                        size = responseElement.getElementsByTagName("Size");
                        size = UTILS_GetNodeText(size[0]);
                        size = (size-(size%1024))/1024;
                        span_size.innerHTML = size+"kb";

                        span_date = document.createElement("span");
                        span_date.setAttribute("class","date");
                        date = responseElement.getElementsByTagName("Date");
                        date = UTILS_GetNodeText(date[0]);
                        span_date.innerHTML = date;
                        div_top = document.createElement("div");
                        div_top.setAttribute("id","seed2_content_center_top");

                        div_top.appendChild(span_name);
                        div_top.appendChild(span_size);
                        div_top.appendChild(span_date);

                        li.appendChild(div_top);

                        span_descr = document.createElement("span");
                        description = responseElement.getElementsByTagName("Description");
                        description = UTILS_GetNodeText(description[0]);
                        span_descr.innerHTML = description;

                        div_descr = document.createElement("div");
                        div_descr.setAttribute("id","seed2_content_center_description");

                        div_descr.appendChild(span_descr);

                        li.appendChild(div_descr);

                        list.appendChild(li);
                    }
                }
            }
            content = document.getElementById("seed2_content_center");
            content.appendChild(list);
        }
        else if (Status == 500)
        {
            document.write("500: "+HttpRequest.responseText);
        }
        else
        {
            document.write("Erro: "+HttpRequest.statusText);
        }
    }
    return "";
}

window.onload = ajax(makeSOAPEnvelope(makeSOAPContent("getDocuments",[],[])),"http://" + hostService + "/" + services + "/" + docService,receiveResponse,"getDocuments");
