/*
 * seed2_install.js
 *
 * Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of portal
 *
 * portal is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/*
 * This file contains all functions used in SEED2 project page:
 * Monitoramento Automatico dos Laboratorios das Escolas Publicas
 * Brasileiras.
 * We used Web Services concepts with AJAX to get information about dynamic
 * contents (i.e. new versions of documentations)
 *
 * @author Rubens Massayuki Suguimoto
 */

var XMLConf = UTILS_OpenXMLFile("http://proinfodata.c3sl.ufpr.br/seed/conf/conf.xml");
var hostService = UTILS_GetTag(XMLConf, "host");
var services = UTILS_GetTag(XMLConf, "services");
var installService = UTILS_GetTag(XMLConf, "installservice");
var docService = UTILS_GetTag(XMLConf, "docservice");
var seed2Service = UTILS_GetTag(XMLConf, "seed2service");

/**
 * @brief Validates the INEP through the AJAX function
 *
 * @param INEP    INEP school
 *
 * @author   Renan Franca de Miranda
 */
function validate(INEP)
{
    var content;

    content = document.getElementById("seed2_content_center_host_error");
    content.innerHTML = "";

    content = document.getElementById("seed2_content_center_port_error");
    content.innerHTML = "";

    content = document.getElementById("seed2_content_center_user_error");
    content.innerHTML = "";

    content = document.getElementById("seed2_content_center_passwd_error");
    content.innerHTML = "";

    if(INEP != "")
    {
        ajax(makeSOAPEnvelope(makeSOAPContent("verifyId",[INEP],["string"])),"http://" + hostService + "/" + services + "/" + seed2Service, receiveResponse,"verifyId");
    }
    else
    {
        content = document.getElementById("seed2_content_center_inep_error");
        content.innerHTML = "INEP inválido.";
    }
}

/**
 * @brief Returns the node as a regular expression applied
 *
 * @param parent    The root node of HTML DOM
 *
 * @author   Renan Franca de Miranda
 */
function catch_child(parent) {
    var exp = new RegExp("[A-z|0-9|:]*Return","g");

    for(parent = parent.childNodes[0]; parent.tagName != undefined; parent = parent.childNodes[0])
    {
        result = exp.exec(parent.tagName);
        if(result != null)
        {
            return parent;
        }
    }
    return "null";
}

/**
 * @brief Returns the node as a regular expression applied
 *
 * @param parent    The root node of HTML DOM
 *
 * @author   Renan Franca de Miranda
 */
function create_list_data(HttpRequest) {
    var response, content;
    var parent, child, removed;
    var inep, uf, city, name, cep, download;

    expand(document.getElementById('seed2_content_center_list'));

    expand(document.getElementById('seed2_content_center_response_table'));

    inep = document.getElementById("seed2_content_center_inep_response");
    response = HttpRequest.responseXML.getElementsByTagName("INEP");
    inep.innerHTML = UTILS_GetNodeText(response[0]);

    uf = document.getElementById("seed2_content_center_uf_response");
    response = HttpRequest.responseXML.getElementsByTagName("UF");
    uf.innerHTML = UTILS_GetNodeText(response[0]);

    city = document.getElementById("seed2_content_center_city_response");
    response = HttpRequest.responseXML.getElementsByTagName("City");
    city.innerHTML = UTILS_GetNodeText(response[0]);

    name = document.getElementById("seed2_content_center_name_response");
    response = HttpRequest.responseXML.getElementsByTagName("Name");
    name.innerHTML = UTILS_GetNodeText(response[0]);

    cep = document.getElementById("seed2_content_center_cep_response");
    response = HttpRequest.responseXML.getElementsByTagName("CEP");
    cep.innerHTML = UTILS_GetNodeText(response[0]);

    return "";
}

/**
 * @brief Show or hide the requested content
 *
 * @param content    Content to be displayed or hidden
 *
 * @author   Renan Franca de Miranda
 */
function expand(content)
{
    if(content.style.display == "none")
    {
        content.style.display = "";
    }
    else
    {
        content.style.display = "none";
    }
}

/**
 * @brief Hide the requested content
 *
 * @param content    Content to be hidden
 *
 * @author   Renan Franca de Miranda
 */
function contract(content)
{
    content.style.display = "none";
}

/**
 * @brief Does the installation page back to default
 *
 * @author   Renan Franca de Miranda
 */
function cancel()
{
    expand(document.getElementById('seed2_content_center_list'));
    expand(document.getElementById('seed2_content_center_response_table'));
    expand(document.getElementById('seed2_content_center_response_confirm'));
}

/**
 * @brief Get the values from installation page and calls the AJAX function to assemble the package
 *
 * @author   Renan Franca de Miranda
 */
function make_package() {
    var inep, host, port, user, passwd;

    inep = document.getElementById("inep").value;
    host = document.getElementById("host").value;
    port = document.getElementById("port").value;
    user = document.getElementById("user").value;
    passwd = document.getElementById("passwd").value;

    ajax(makeSOAPEnvelope(makeSOAPContent("makePackage",[inep,host,port,user,passwd],["string","string","string","string","string"])),"http://" + hostService + "/" + services + "/" + installService,receiveResponse,"makePackage");
}

/*
 * Parse AJAX HTTP SOAP response.
 *
 * @param HttpRequest    XML HTTP Request object with SOAP response.
 * @return   empty string
 *
 * @author Rubens Massayuki Suguimoto
 * @author Renan Franca de Miranda
 */
function receiveResponse(HttpRequest){

    var Status;
    var response;
    var parent, child, removed;
    var p, content;

    if (HttpRequest.readyState == 4)
    {
        try
        {
            Status = HttpRequest.status;
        }
        catch(e)
        {
            document.write(e);
            return "";
        }
        if(Status == 200)
        {
            if(UTILS_IdentifyBrowser() == 0)
            {
                //response = catch_child(HttpRequest.responseXML);
                response = HttpRequest.responseXML.lastChild.firstChild.firstChild;
            }
            else
            {
                response = HttpRequest.responseXML.firstChild.firstChild.firstChild;
            }
            var multiRefTags = HttpRequest.responseXML.getElementsByTagName("multiRef");
            switch(response.tagName)
            {
                case "getAgentVersionResponse":
                    parent = document.getElementById("seed2_content_center_download_name");
                parent.innerHTML += " v"+UTILS_GetNodeText(response);
                break;

                case "getINEPInfoResponse":
                    create_list_data(HttpRequest);
                break;

                case "verifyIdResponse":
                    var multiRefContent = UTILS_GetNodeText(multiRefTags[0]);

                var host, port, user, passwd, passwd_2;
                var reg_exp_1 = new RegExp("[^A-Z|^a-z|^0-9|^.]");
                var reg_exp_2 = new RegExp("[^0-9]");
                var reg_exp_3 = new RegExp("^[^A-Z|^a-z]");
                var reg_exp_4 = new RegExp("[^A-Z|^a-z|^0-9|^-|^_]");
                var INEP = document.getElementById("inep").value;
                var response_text = UTILS_GetNodeText(response);
                content = document.getElementById("seed2_content_center_inep_error");
                if(UTILS_GetNodeText(response) == "true")
                    //if(multiRefContent == "true")
                {
                    content.innerHTML = "";
                    content = document.getElementById("seed2_content_center_proxy_list");
                    if(content.style.display == "")
                    {
                        host = document.getElementById("host").value;
                        port = document.getElementById("port").value;
                        user = document.getElementById("user").value;
                        passwd = document.getElementById("passwd").value;
                        passwd_2 = document.getElementById("passwd_2").value;

                        if(host == "" && port == "" && user == "" && passwd == "" && passwd_2 == "")
                        {
                            content = document.getElementById("seed2_content_center_host_error");
                            content.innerHTML = "Preencha algum campo.";
                        }
                        else if(host == "" && port != "")
                        {
                            content = document.getElementById("seed2_content_center_host_error");
                            content.innerHTML = "Digite o host.";
                        }
                        else if (user != "" && host == "")
                        {
                            content = document.getElementById("seed2_content_center_host_error");
                            content.innerHTML = "Digite o host.";
                        }
                        else if (user == "" && (passwd != "" || passwd_2 != ""))
                        {
                            content = document.getElementById("seed2_content_center_user_error");
                            content.innerHTML = "Digite o usuário.";
                        }
                        else if (passwd != passwd_2)
                        {
                            content = document.getElementById("seed2_content_center_passwd_error");
                            content.innerHTML = "Senha não confirmada.";
                        }
                        else if (reg_exp_1.test(host))
                        {
                            content = document.getElementById("seed2_content_center_host_error");
                            content.innerHTML = "Apenas letras e/ou números.";
                        }
                        else if (reg_exp_2.test(port))
                        {
                            content = document.getElementById("seed2_content_center_port_error");
                            content.innerHTML = "Apenas números.";
                        }
                        else if (reg_exp_3.test(user))
                        {
                            content = document.getElementById("seed2_content_center_user_error");
                            content.innerHTML = "Usuário deve começar com letra.";
                        }
                        else if (reg_exp_4.test(user))
                        {
                            content = document.getElementById("seed2_content_center_user_error");
                            content.innerHTML = "Nome de usuário inválido.";
                        }
                        else
                        {
                            ajax(makeSOAPEnvelope(makeSOAPContent("getINEPInfo",[INEP],["string"])),"http://" + hostService + "/" + services + "/" + installService,receiveResponse,"getINEPInfo");
                            document.getElementById("seed2_content_center_host_response").innerHTML = host;
                            if(port == "")
                            {
                                port = document.getElementById("port").value = "80";
                                document.getElementById("seed2_content_center_port_response").innerHTML = "Padrão (80)";
                            } else
                            {
                                document.getElementById("seed2_content_center_port_response").innerHTML = port;
                            }
                            document.getElementById("seed2_content_center_user_response").innerHTML = user;
                            document.getElementById("seed2_content_center_passwd_response").innerHTML = passwd.replace(/[a-z|A-Z|0-9]/g,"*");
                        }
                    }
                    else
                    {
                        ajax(makeSOAPEnvelope(makeSOAPContent("getINEPInfo",[INEP],["string"])),"http://" + hostService + "/" + services + "/" + installService,receiveResponse,"getINEPInfo");
                        host = document.getElementById("host").value = "";
                        port = document.getElementById("port").value = "";
                        user = document.getElementById("user").value = "";
                        passwd = document.getElementById("passwd").value = "";
                        document.getElementById("seed2_content_center_host_response").innerHTML = "Sem uso";
                        document.getElementById("seed2_content_center_port_response").innerHTML = "Sem uso";
                        document.getElementById("seed2_content_center_user_response").innerHTML = "Sem uso";
                        document.getElementById("seed2_content_center_passwd_response").innerHTML = "Sem uso";
                    }
                }
                else
                {
                    content.innerHTML = "INEP inválido.";
                }
                break;

                case "makePackageResponse":
                    var link, down_link, down_name, down_size, down_date, date;

                contract(document.getElementById("seed2_content_center_response_table"));

                expand(document.getElementById("seed2_content_center_download"));

                expand(document.getElementById("seed2_content_center_OS_alert"));

                link = HttpRequest.responseXML.getElementsByTagName("URL");
                down_link = document.getElementById("seed2_content_center_download_link");
                down_link.setAttribute("href",UTILS_GetNodeText(link[0]));

                down_name = document.getElementById("seed2_content_center_download_name");
                response = HttpRequest.responseXML.getElementsByTagName("PackageName");
                down_name.innerHTML = UTILS_GetNodeText(response[0]);

                down_size = document.getElementById("seed2_content_center_download_size");
                response = HttpRequest.responseXML.getElementsByTagName("Size");
                response = UTILS_GetNodeText(response[0]);
                response /= 1024*1024;
                down_size.innerHTML = response.toFixed(1)+"mb";

                down_date = document.getElementById("seed2_content_center_download_date");
                down_date.setAttribute("id","seed2_content_center_download_date");
                date = new Date();
                down_date.innerHTML += date.getDate()+"/"+(date.getMonth()+1)+"/"+date.getFullYear();

                ajax(makeSOAPEnvelope(makeSOAPContent("getAgentVersion")),"http://" + hostService + "/" + services + "/" + seed2Service,receiveResponse,"getAgentVersion");

                break;
            }
        }
        else if (Status == 500)
        {
            var text = document.getElementById("seed2_content_center_inep_error");

            text.innerHTML = "Erro interno no servidor.";
        }
        else if (Status == 503)
        {
            var text = document.getElementById("seed2_content_center_inep_error");

            text.innerHTML = "Servidor fora do ar.";
        }
        else
        {
            document.write("Erro: "+HttpRequest.statusText);
        }
    }
    return "";
}

/**
 * @brief Reset the values of the installation page
 *
 * @author   Renan Franca de Miranda
 */
function reset() {
    document.getElementById("inep").value="";

    document.getElementById("seed2_content_center_proxy_yes").checked=false;
    document.getElementById("seed2_content_center_proxy_no").checked=true;

    document.getElementById("host").value="";
    document.getElementById("port").value="";
    document.getElementById("user").value="";
    document.getElementById("passwd").value="";
    document.getElementById("passwd_2").value="";
}

function gotoPage(url){
    window.location = url;
}

//window.onload = reset();
