/*
 * seed2_tabs.js
 *
 * Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of portal
 *
 * portal is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/*
 * This file contains all functions related to tabs functionalities used in
 * SEED2 project page:  Monitoramento Automatico dos Laboratorios das Escolas
 * Publicas Brasileiras.
 */

var tabsVector = new Array();
tabsVector[0] = new stdTab('menu_ProInfo','div_proinfo');
tabsVector[1] = new stdTab('menu_UCAClassmate','div_uca_class');
tabsVector[2] = new stdTab('menu_UCAServer','div_uca_server');
tabsVector[3] = new stdTab('menu_Projector','div_projetor');

/**
 * @brief Switch between tabs
 *
 * @param menu HTML id to determine which project tab should be selected.
 * @param conteudo Graph url.
 *
 * @author Renan Franca de Miranda
 * @author Aryane Ast dos Santos
 */
function switchTab(menu)
{
    var i, m, child, parent, p, aba;
    parent = document.getElementById("seed2_content_center");
    child = document.getElementById("seed2_content_center_no_data");
    if(child)
        parent.removeChild(child);

    /* resets the elements classes */
    for (i=0; i < tabsVector.length; i++)
    {
        m = document.getElementById(tabsVector[i].menu);
        if (m)
            m.className = 'aba-menu';
    }
    m = document.getElementById(menu);
    /* selects the menu tab and makes it green */
    if (m)
        m.className = 'aba-menu-sel';

    var content = makeContent();

    /* if there's any content, create the proper graph */
    if((content != "no_data") && (content != "manutencao"))
    {
        graf(content);
    }
    else if(content == "no_data")
    {
        /* this removeGraph function is needed here because the graph takes a
         * while to be loaded, and when the user switches quickly between tabs
         * the other project/tab graph keeps loading and it appears in the
         * current tab, so we wait until it has appeared (1 sec) and then
         * remove it. */
        setTimeout('removeGraph()', 1000);
        p = document.createElement("p");
        p.id = "seed2_content_center_no_data";
        p.innerHTML = "Não existem dados a serem visualizados."
            parent.appendChild(p);
        p.className = "informativo";
    }
    else if(content == "manutencao")
    {
        setTimeout('removeGraph()', 1000);
        p = document.createElement("p");
        p.id = "seed2_content_center_no_data";
        p.innerHTML = "Em manutenção."
            parent.appendChild(p);
        p.className = "informativo";
    }

    updateURL();
    reloadLinks();
}

/**
 * @brief Remove a graph from the HTML
 *
 * @author Aryane Ast dos Santos
 */
function removeGraph()
{
    var i, m, child, parent, p, aba, content;
    parent = document.getElementById("seed2_content_center");
    if (parent)
        child = document.getElementById("line_list");
    if(child)
        parent.removeChild(child);
    child = document.getElementById("seed2_content_center_graph");
    if(child)
        parent.removeChild(child);

}

/**
 * @brief Atualize the left menu links, replacing the URL hash value with
 * the new project.
 *
 * @author Adriano da Luz
 * @author Aryane Ast dos Santos
 */
function reloadLinks()
{
    var links = document.getElementsByTagName("a");
    var project = (window.location.hash).substring(1);
    for(var i=0; i<links.length; i++)
    {
        classe = links[i].getAttribute("class");
        if(classe == "menu")
        {
            var link = links[i].href.split("#");
            links[i].href = link[0]+"#"+project;
        }
        else if(classe == "submenu")
        {
            var link = links[i].href.split("#");
            links[i].href = link[0]+"#"+project;
        }
    }
}

/**
 * @brief Creates a new stdTab instance with passed atributes.
 *
 * @param menu HTML project id.
 * @param conteudo Graph url.
 *
 * @author Renan França de Miranda
 */
function stdTab(menu, conteudo)
{
    this.menu = menu;
    this.conteudo = conteudo;
}

/**
 * @brief Get the current project from the selected tab
 *
 * @author Aryane Ast dos Santos
 */
function projectName()
{
    for (var i=0; i < tabsVector.length; i++)
    {
        var m = document.getElementById(tabsVector[i].menu);
        if (m.className == 'aba-menu-sel')
            return m.id.substring(5);
    }
}

/**
 * @brief Puts a hash value with the new project name on the URL
 *
 * @author Aryane Ast dos Santos
 */
function updateURL()
{
    var project = projectName();
    if (project)
        window.location.hash = project;
}

function gotoPage(url){
    window.location = url;
}

/**
 * @brief Make graph URL content
 *
 * @author Aryane Ast dos Santos
 */
function makeContent()
{
    var content;
    var project = projectName();
    var graph = graphType();

    if ((graph == "Disp") && ((project == "UCAServer") || (project == "UCAClassmate")))
        return "no_data";
    else if ((graph == "Invent") && ((project == "UCAServer") || (project == "UCAClassmate")))
        return "no_data";
    else if ((graph == "Audit") && ((project == "UCAClassmate") || (graph == "UCAServer")))
        return "no_data";
    else if ((graph == "Alert") && ((project == "UCAServer") || (project == "UCAClassmate") || (project == "Projector")))
        return "no_data";

    return ("/tomcat/pentaho/"+project+graph);
}

/**
 * @brief Gets graph type from the URL
 *
 * @author Aryane Ast dos Santos
 */
function graphType()
{
    var project = window.location.href.split("/");
    project = project[5];
    project = project.split("#");
    project = project[0];
    project = project.split(".");
    project = project[0];
    project = project.replace(project[0], project[0].toUpperCase());
    return(project);
}
