/*
 * Copyright (C) 2004-2010 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of server
 *
 * server is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* General libs */
import java.util.*;
import java.text.*;
import java.lang.Long;

/* Postgre and SQL libs */
import java.sql.ResultSet;

/* File libs */
import java.io.IOException;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.InputStream;

public class Seed2Install {

/* Attributes */
private String table_school;
private String package_gen;
private String package_dest;
private String host;

/**
 * Seed2Install service constructor.
 *
 * @author              Rubens Massayuki Suguimoto
*/
public Seed2Install() {
    XmlUtil installConf = new XmlUtil("./seed2/conf.xml");
    String installTag = "install_config";

    /* Get information from configuration file */
    table_school = installConf.getTextValue(installConf.getTag(installTag),
                            "table_school");
    host = installConf.getTextValue(installConf.getTag(installTag),
                            "host");
    package_dest = installConf.getTextValue(installConf.getTag(installTag),
                            "package_dest");
    package_gen = installConf.getTextValue(installConf.getTag(installTag),
                            "package_gen");
}

/**
 * Get school information by Inep's number.
 *
 * @author            Rubens Massayuki Suguimoto
 * @param     inep    School's INEP number
 * @return            Seed2School
*/
public Seed2School getINEPInfo(String inep)
throws Exception {
    Seed2School school = new Seed2School();

    /* Initialize school information */
    school.INEP = inep;
    school.Name = "";
    school.CEP = "";
    school.UF = "";
    school.City = "";
    school.Address = "";
    school.MessageCode = 0;
    school.MessageError = "";

    /* Create SQL query to get INEP information from data base */
    String table = this.table_school;
    String query = "SELECT * FROM " + table + " WHERE esc_inep=\'" +
                    inep + "\'";
    ResultSet rs;

    System.out.println("Install: Querying INEP information. (" + inep + ")");
    /* Create connection instace */
    DBConnection dbcon = new DBConnection();
    dbcon.connect();

    rs = dbcon.executeQuery(query);

    System.out.println("Install: Retrieve result to INEP: " + inep);
    /* Retrive result from data base */
    if (rs.next() == true)
    {
        school.Name = rs.getString("esc_nome");
        school.CEP = rs.getString("esc_cep");
        school.UF = rs.getString("esc_uf");
        school.City = rs.getString("esc_municipio");
        school.Address = rs.getString("esc_endereco");
        school.MessageCode = 200;
        school.MessageError = "";
    }
    else
    {
        school.MessageCode = 404;
        school.MessageError = "Not Found";
    }

    System.out.println("Install: Retrieve INEP information done! (" +
                        inep + ")");
    dbcon.close();

    return school;
}

/**
 * Create agent package and return the package information
 *
 * @author                Rubens Massayuki Suguimoto
 * @param     	inep      School's INEP number
 * @param    	host      Agent's proxy host
 * @param     	port      Agent's proxy port
 * @param     	user      Agent's proxy user
 * @param     	passwd    Agent's proxy password
 * @return            	  Seed2Package information
*/
public Seed2Package makePackage(String inep, String host, String port,
                                String user, String passwd)
                                throws IOException, Exception {
    Seed2Package install_pkg = new Seed2Package();
    Seed2 seed2Service = new Seed2();
    String line;
    String debug = "";
    FileUtil fileUtil = new FileUtil();
    long packageSize;

    /* Initialize install package */
    install_pkg.URL = "http://" + this.host + "/package/agent_" + inep +
                      ".run";
    install_pkg.Size = "0";
    install_pkg.PackageName = "agent_" + inep + ".run";
    install_pkg.MessageCode = 200;
    install_pkg.MessageError = "";

    /* Get runtime enviroment */
    Runtime runtime = Runtime.getRuntime();

    System.out.println("Install: Creating package.");

    if (seed2Service.verifyId(inep) == false) {
        install_pkg.MessageError = "Invalid INEP code";
        install_pkg.MessageCode = 400;
        return install_pkg;
    }

    String[] execStr = {"sh", this.package_gen, inep, host, port,
                            user, passwd};
    System.out.println("Install: Executing script. INEP: " + inep);
    Process proc = runtime.exec(execStr);

    /* Put the command output on BufferedReader */
    InputStream inputstream = proc.getErrorStream();
    InputStreamReader inputstreamreader = new InputStreamReader(inputstream);
    BufferedReader bufferedreader = new BufferedReader(inputstreamreader);


    /* Read command output */
    while ((line = bufferedreader.readLine()) != null) {
        debug = debug + line;
    }
    System.out.println("Install: Output: " + debug);

    /* Check for command failure */
    try {
        if (proc.waitFor() != 0) {
            System.out.println("Install: Exit value = " + proc.exitValue());
            install_pkg.MessageError = "value:" + proc.exitValue() +
                                      "\n debug: "+ debug;
            install_pkg.MessageCode = 500;
            return install_pkg;
        }
    } catch (InterruptedException e) {
        System.out.println("Install: Error: " + e);
        install_pkg.MessageError = e.toString();
        install_pkg.MessageCode = 500;
        return install_pkg;
    }

    /* Get package size in bytes */
    packageSize = fileUtil.getFileSize("/" + this.package_dest + "/agent_" +
                                       inep + ".run");

    /* Set package size in return message */
    install_pkg.Size = Long.toString(packageSize);

    System.out.println("Install: Package done!");

    return install_pkg;
}

/*
 * Verify a INEP string using verifyId method from Seed2Service
 *
 * @author          Rubens Massayuki Suguimoto
 * @param   inep    School identifier
 * @return          String
*/
public String verifyId(String inep)
throws Exception {
    Seed2 seed2Service = new Seed2();

    if (seed2Service.verifyId(inep) == false) {
        return "false";
    } else {
        return "true";
    }
}

}
