#!/usr/bin/env python

# Copyright (C) 2010 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR

# This file is part of server

# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.


from SOAPpy import Config, HTTPTransport, SOAPAddress, WSDL, SOAPProxy
import base64;

# This scripts test the methods offered by webservice running at 'url'.
# The respective webservice is the dump service.

# HTTP authentication class, used to test the authentication
class myHTTPTransport(HTTPTransport):
    username = None
    passwd = None

    @classmethod
    def setAuthentication(cls,u,p):
        print "Setting user: "+u+" passwd: "+ p;
        cls.username = u;
        cls.passwd = p;

    def call(self, addr, data, namespace, soapaction=None, encoding=None,
             http_proxy=None, config=Config):

        if not isinstance(addr, SOAPAddress):
            addr=SOAPAddress(addr, config);

        if self.username != None:
            addr.user = self.username+":"+self.passwd;

        return HTTPTransport.call(self, addr, data, namespace, soapaction, encoding, http_proxy, config);

url = 'http://seed.c3sl.ufpr.br:8888/axis/services/Seed2DumpService';
wsdlurl = url+'?wsdl';

DEBUG=0;

# Tests without authentication
print 'AUTH: Testing without authentication.'
wsdlObject = WSDL.Proxy(wsdlurl);

# SOAP and HTTP debug options
wsdlObject.soapproxy.config.dumpSOAPOut = DEBUG;
wsdlObject.soapproxy.config.dumpSOAPIn = DEBUG;
wsdlObject.soapproxy.config.dumpHeadersIn = DEBUG;
wsdlObject.soapproxy.config.dumpHeadersOut = DEBUG;

# print available methods
print 'Available methods:'
for method in wsdlObject.methods.keys() :
    print method
    ci = wsdlObject.methods[method]
    # you can also use ci.inparams
    for param in ci.inparams :
        # list of the function and type
        # depending of the wsdl...
        print param.name.ljust(20) , param.type
    print

print('==========')
print('1 - getLastDumpDate method')
try:
    print('1.1: ' + wsdlObject.getLastDumpDate())
except:
    print('1.1: Unexpected error.')

print('==========')
print('2 - getDump method')
try:
    dump64 = wsdlObject.getDump()
    print('2.1: ' + dump64)
    print('2.1 (decoded): ' + base64.decodestring(dump64))
except:
    print('2.1: Unexpected error.')

print('==========')
# Tests with HTTP basic authentication
print 'AUTH: Testing with HTTP basic authentication.'
user = 'mec'
passwd = 'teste123'

myHTTPTransport.setAuthentication(user, passwd);

wsdlObject = WSDL.Proxy(wsdlurl, transport=myHTTPTransport);

# SOAP and HTTP debug options
wsdlObject.soapproxy.config.dumpSOAPOut = DEBUG;
wsdlObject.soapproxy.config.dumpSOAPIn = DEBUG;
wsdlObject.soapproxy.config.dumpHeadersIn = DEBUG;
wsdlObject.soapproxy.config.dumpHeadersOut = DEBUG;

# print available methods
print 'Available methods:'
for method in wsdlObject.methods.keys() :
    print method
    ci = wsdlObject.methods[method]
    # you can also use ci.inparams
    for param in ci.inparams :
        # list of the function and type
        # depending of the wsdl...
        print param.name.ljust(20) , param.type
    print

print('==========')
print('1 - getLastDumpDate method')
print('1.1: ' + wsdlObject.getLastDumpDate())

print('==========')
print('2 - getDump method')
dump64 = wsdlObject.getDump()
print('2.1: ' + dump64)
print('2.1 (decoded): ' + base64.decodestring(dump64))

