﻿# Copyright (C) 2004-2011 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of windows-coleta
#
# windows-coleta is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

#coding: utf-8
import os
import sys
import _winreg
import shutil
import subprocess
import urllib
from time import localtime, strftime
from xml.etree.ElementTree import tostring
import collect
import glob

# ==========================================
#       Constants
# ==========================================
# TODO: Check compatibility with 64bit Windows (Program Files(x86) folder)
PROINFODATAPATH = os.environ["ProgramFiles"] + "\\ProInfoData"
URL = ""
# Log lifetime in days
LOGLIFETIME = 30

# ==========================================
#       Classes definitions
# ==========================================
# Class log: log manipulation
class Log():
    # Verify if today's log exist. If exists, the log is opened. Otherwise,
    # a new one is created
    def __init__(self):
        date = strftime("%Y%m%d", localtime())
        logpath = PROINFODATAPATH + "\log"
        logfilename = date + ".log"
        if (os.path.exists(logpath + "\\" + logfilename)):
            self.logfile = file(logpath + "\\" + logfilename,"a")
        else:
            self.logfile = file(logpath + "\\" + logfilename,"w")
        self.write("START: Proinfodata Agent Windows.")

    def write(self, str):
        self.logfile.write(strftime("%I:%M:%S", localtime()) + ": ")
        self.logfile.write(str + "\n")

    def close(self):
        self.logfile.close()

    def flush(self):
        self.logfile.flush()

class clientError():
    def __init__(self, retCode, error):
        self.code = retCode
        self.errorMsg = error

# ==========================================
#       Functions definitions
# ==========================================
# Get the proinfodata version
def getVersion():
    return collect.getRegistryValue("HKEY_LOCAL_MACHINE", "SOFTWARE\\ProInfoData", "Version")

# Write INEP in conf\inep file
def writeInepConf(inep):
    inepConfFile = file(PROINFODATAPATH + "\\conf\\inep", "w")
    inepConfFile.write(inep)
    inepConfFile.close()

# Write Version in conf\version file
def writeVersionConf(version):
    versionConfFile = file(PROINFODATAPATH + "\\conf\\version", "w")
    versionConfFile.write(version)
    versionConfFile.close()

# Call client.exe returning the returncode and the output
def callClient(args):
    clientPath = "\"" + PROINFODATAPATH + "\\bin\\client.exe" + "\""
    proc = subprocess.Popen(clientPath + args, stdout=subprocess.PIPE,
    stderr=subprocess.PIPE, shell=True)
    out = proc.communicate()

    return (proc.returncode, out)

# Check for updates
def verifyUpdate():
    args = " --update --url=" + URL

    (phost, pport, puser, ppass) = getProxyInfo()

    if phost != "":
            args += " --phost=" + phost
            if pport != "":
                args += " --pport=" + pport
            if puser != "" or ppass != "":
                    args += " --puid=" + puser + " --ppasswd=" + ppass

    (returnCode, output) = callClient(args)
    if returnCode == 0:
        return 0

    if returnCode == 4:
        updatelink = output[0].split("\n")[0]
        return updatelink
    else:
        raise clientError(returnCode, output)

# Save the old collect-data file
def backupCollectData():
    if os.path.exists(PROINFODATAPATH + "\\data\\collect-data.xml"):
        date = strftime("%Y%m%d-%I%M%S", localtime())
        shutil.copy(PROINFODATAPATH + "\\data\\collect-data.xml",\
        PROINFODATAPATH + "\\data\\collect-data" + date + ".xml")
    return 0

# Delete old log files
def deleteOldLogs():
    logPath = PROINFODATAPATH + "\\log"
    today = strftime("%Y%m%d", localtime())
    ageLimit = int(today) - LOGLIFETIME
    for infile in glob.glob(os.path.join(logPath, '*.log')):
        try:
            fileDate = int(infile.split("\\")[-1].split(".")[0].strip())
        except:
            continue

        if fileDate <= ageLimit:
            os.remove(infile)

# Get proxy information from Windows registry
def getProxyInfo():
    phost = collect.getRegistryValue("HKEY_LOCAL_MACHINE", "SOFTWARE\\ProInfoData", "ProxyHost")
    pport = collect.getRegistryValue("HKEY_LOCAL_MACHINE", "SOFTWARE\\ProInfoData", "ProxyPort")
    puser = collect.getRegistryValue("HKEY_LOCAL_MACHINE", "SOFTWARE\\ProInfoData", "ProxyUser")
    ppass = collect.getRegistryValue("HKEY_LOCAL_MACHINE", "SOFTWARE\\ProInfoData", "ProxyPass")

    return (phost, pport, puser, ppass)

# Send the collect-data.xml
def sendData():
    args = " --inventory --url=" + URL + " --inep=" + inep

    (phost, pport, puser, ppass) = getProxyInfo()

    if phost != "":
            args += " --phost=" + phost
            if pport != "":
                args += " --pport=" + pport
            if puser != "" or ppass != "":
                    args += " --puid=" + puser + " --ppasswd=" + ppass

    (returnCode, output) = callClient(args)
    if returnCode != 0:
        raise clientError(returnCode, output)
    return 0

# Create collect-data.xml file
def writeCollectData(collectData):
    collectDataFile = file(PROINFODATAPATH + "\\data\\collect-data.xml", "w")
    collectDataFile.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n")
    collectDataFile.write(tostring(collectData))
    collectDataFile.close()

# Download the update package
def downloadUpdate(link):
    urllib.urlretrieve(link, PROINFODATAPATH + "\\update\\updatePackage.exe")

# Call the update package
def callUpdater():
    updaterPath = "\"" + PROINFODATAPATH + "\\update\\updatePackage.exe" + "\""
    args = "/S"
    proc = subprocess.Popen(updaterPath + args)
    # Wait to be killed
    out = proc.communicate()

# ==========================================
#       Main program
# ==========================================
# Open the logfile
log = Log()

# Delete old log files
try:
    deleteOldLogs()
except:
    log.write("WARNING: Failed to delete old log files.")

# Get Version from Windows Registry
try:
    version = getVersion()
except:
    log.write("ERROR(1): Failed to check Version in Windows registry.")
    log.close()
    sys.exit(1)

# Get INEP from Windows Registry

try:
    inep = collect.getINEP()
except:
    log.write("ERROR(2): Failed to check INEP in Windows registry.")
    log.close()
    sys.exit(2)

# Write inep and version conf files
try:
    writeVersionConf(version)
    writeInepConf(inep)
except:
    log.write("ERROR(3): Cannot write inep or version conf files.")
    log.close()
    sys.exit(3)

# Check if PROINFODATAPATH\bin\client.exe exists
if not (os.path.exists(PROINFODATAPATH + "\\bin\\client.exe")):
    log.write("ERROR(4): client.exe not found.")
    log.close()
    sys.exit(4)

# Check for updates
try:
    updatelink = verifyUpdate()
except clientError, e:
    log.write("ERROR(5): Failed to check for updates. Client returned " + str(e.code) + ".")
    log.write("Client message: " + str(e.errorMsg))
    log.close()
    sys.exit(5)

# If update is needed
if(updatelink):
    log.write("UPDATE: New update package available.")

    # Get remote version
    # The update link is in the format: "http://url/proinfodata-windows_x.x.x.exe
    # where x.x.x is the remote version
    newVersion = updatelink.split("_")[-1].replace(".exe", "")
    log.write("UPDATE: Updating from " + version + " to " + newVersion.strip() + ".")
    try:
        downloadUpdate(updatelink)
    except:
        log.write("ERROR(6): Failed to dowload update package.")
        log.close()
        sys.exit(6)

    # The update package will be an NSIS installer. This installer will kill
    # this process to overwrite the files. After that, the installer will call
    # this process again (now updated)
    try:
        log.write("UPDATE: Stopping for update process.")
        log.flush()
        callUpdater()
    except:
        log.write("ERROR(7): Failed to call the updater.")
        log.close()
        sys.exit(7)
else:
    log.write("UPDATE: No updates are available.")

# Collect data
try:
    collectData = collect.collect()
except:
    log.write("ERROR(8): Failed to collect data.")
    log.close()
    sys.exit(8)

# Write the collect-data.xml file
try:
    writeCollectData(collectData)
except:
    log.write("ERROR(9): Failed to write collect-data.xml.")
    log.close()
    sys.exit(9)

# Send data
try:
    sendData()
except clientError, e:
    log.write("ERROR(10): Failed to send data. Client returned " + str(e.code) + ".")
    log.write("Client message: " + str(e.errorMsg))
    log.close()
    sys.exit(10)
except:
    log.write("ERROR(11): Failed to get the proxy information from Windows registry.")
    log.close()
    sys.exit(11)

# If everything ran ok, exit with success status
log.write("EXIT(0): Success.")
log.close()
sys.exit(0)
